@@ -25,6 +25,7 @@ import hvac
 from hvac.exceptions import VaultError
 from requests import Response
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.hooks.base import BaseHook
 from airflow.providers.hashicorp._internal_client.vault_client import (
     DEFAULT_KUBERNETES_JWT_PATH,
@@ -148,7 +149,7 @@ class VaultHook(BaseHook):
                 warnings.warn(
                     """The usage of role_id for AppRole authentication has been deprecated.
                     Please use connection login.""",
-                    DeprecationWarning,
+                    AirflowProviderDeprecationWarning,
                     stacklevel=2,
                 )
             elif self.connection.extra_dejson.get("role_id"):
@@ -156,7 +157,7 @@ class VaultHook(BaseHook):
                 warnings.warn(
                     """The usage of role_id in connection extra for AppRole authentication has been
                     deprecated. Please use connection login.""",
-                    DeprecationWarning,
+                    AirflowProviderDeprecationWarning,
                     stacklevel=2,
                 )
             elif self.connection.login:
